#!/usr/bin/python3

from sys import argv, exit
from os import walk, path
from random import choice, seed
from textwrap import indent
import time, urllib.parse, re, subprocess

from article_utils import parse_metadata
from page_shares import ADJECTIVES
from rfc822 import stringify_date

if len(argv) <= 1:
    print("No directory was supplied")
    exit(-1)

if len(argv) <= 2:
    print("No address was supplied")
    exit(-1)

seed()

address = argv[2]

# todo: Find the latest pubDate
feed = f"""<rss version="2.0">
    <channel>
        <title>mjestečko</title>
        <link>{address}</link>
        <description>Personal blog of one {choice(ADJECTIVES)} Veclav Talica</description>
        <language>en</language>
        <lastBuildDate>{stringify_date(time.gmtime(int(time.time())))}</lastBuildDate>
"""

body_taker = re.compile(r"<body>(.*)</body>", re.DOTALL)

for root, dirs, _ in walk(argv[1]):
    for d in dirs:
        metadata = parse_metadata(path.abspath(root + '/' + d + "/page.mmd"))
        feed += (
            "    <item>\n"
            f"""        <title>{metadata.get("Title", "No title!? ;-;")}</title>\n"""
        )
        body = subprocess.getoutput(f"./tools/mmd/build/multimarkdown {root}/{d}/page.mmd")
        feed += (
            "        <description>\n"
            "            <![CDATA[\n"
            f"{indent(body_taker.search(body)[1], ' ' * 12)}\n"
            "            ]]>\n"
            "        </description>\n"
        )
        if "Date" in metadata:
            feed += \
                f"""        <pubDate>{stringify_date(metadata["Date"])}</pubDate>\n"""
        feed += (
            f"""        <guid>/articles/{d}</guid>\n"""
            f"""        <link>{address}/articles/{urllib.parse.quote(d)}</link>\n"""
            "    </item>\n"
        )
    break

feed += """    </channel>
</rss>"""

print(feed)
