#!/usr/bin/python3

from sys import argv, exit
from os import walk, path
from random import choice, seed
import time, urllib.parse

from article_utils import parse_metadata
from page_shares import wrap_page, ADJECTIVES, MONTHS

if len(argv) <= 1:
    print("No directory was supplied")
    exit(-1)

seed()

page_metadata = """Title:  mjestečko
CSS:    /style.css

"""

page = f"""Personal blog of one {choice(ADJECTIVES)} Veclav Talica.

### Articles ###

"""

artciles = {}
for root, dirs, _ in walk(argv[1]):
    for d in dirs:
        metadata = parse_metadata(path.abspath(root + '/' + d + "/page.mmd"))
        article = urllib.parse.quote(d)
        artciles[article] = {
            "metadata": metadata
        }
    break

for title in sorted(artciles.keys(), key=lambda a: artciles[a]["metadata"].get("Date", time.gmtime(0)), reverse=True):
    article = artciles[title]
    metadata = article["metadata"]
    page += (
        f"""[{metadata.get("Title", "No title given! What a clusterfuck!")}](/articles/{title}.html)\n\n"""
        f""">{metadata.get("Brief", "")}\n\n"""
    )

curtime = time.gmtime(int(time.time()))
page += f"Last compiled: *{MONTHS[curtime.tm_mon]} {curtime.tm_mday}, {curtime.tm_year} {curtime.tm_hour}:{curtime.tm_min:02d} UTC*\n\n"

print(page_metadata + wrap_page(page))
